import { __assign, __extends } from "tslib";
import { AbstractCanvas } from '@antv/g-base';
import { applyClipChildren, drawPathChildren } from './util/draw';
import { setTransform, setClip } from './util/svg';
import { sortDom } from './util/dom';
import EventController from '@antv/g-base/lib/event/event-contoller';
import * as Shape from './shape';
import Group from './group';
import Defs from './defs';
var Canvas = /** @class */ (function (_super) {
    __extends(Canvas, _super);
    function Canvas(cfg) {
        return _super.call(this, __assign(__assign({}, cfg), { autoDraw: true })) || this;
    }
    // 覆盖基类中的 set 方法
    Canvas.prototype.set = function (name, value) {
        // autoDraw 不可修改，始终为 true
        // TODO: 应该在控制台给出 Warning 提示，引导用户避免这种用法。需要在 @antv/util 中提供通用的 warning 方法，便于在其他 antv 项目中使用
        if (name === 'autoDraw') {
            this.cfg[name] = true;
        }
        else {
            _super.prototype.set.call(this, name, value);
        }
    };
    /**
     * 一些方法调用会引起画布变化
     * @param {ChangeType} changeType 改变的类型
     */
    Canvas.prototype.onCanvasChange = function (changeType) {
        var context = this.get('context');
        var el = this.get('el');
        if (changeType === 'sort') {
            var children_1 = this.get('children');
            if (children_1 && children_1.length) {
                sortDom(this, function (a, b) {
                    return children_1.indexOf(a) - children_1.indexOf(b) ? 1 : 0;
                });
            }
        }
        else if (changeType === 'clear') {
            // el is null for canvas
            if (el) {
                el.innerHTML = '';
            }
        }
        else if (changeType === 'matrix') {
            setTransform(this);
        }
        else if (changeType === 'clip') {
            this.applyClip(context);
        }
        else if (changeType === 'changeSize') {
            el.setAttribute('width', "" + this.get('width'));
            el.setAttribute('height', "" + this.get('height'));
        }
    };
    Canvas.prototype.getShapeBase = function () {
        return Shape;
    };
    Canvas.prototype.getGroupBase = function () {
        return Group;
    };
    // 复写基类的方法生成标签
    Canvas.prototype.createDom = function () {
        var element = document.createElementNS('http://www.w3.org/2000/svg', 'svg');
        var context = new Defs(element);
        element.setAttribute('width', "" + this.get('width'));
        element.setAttribute('height', "" + this.get('height'));
        // 缓存 context 对象
        this.set('context', context);
        return element;
    };
    // 复写基类的 draw 方法
    Canvas.prototype.draw = function () {
        var context = this.get('context');
        this.applyClip(context);
        this.drawPath(context);
    };
    Canvas.prototype.applyClip = function (context) {
        var children = this.getChildren();
        setClip(this, context);
        if (children.length) {
            applyClipChildren(context, children);
        }
    };
    Canvas.prototype.drawPath = function (context) {
        var children = this.getChildren();
        if (children.length) {
            drawPathChildren(context, children);
        }
    };
    // 覆盖基类中的 initEvents 方法
    Canvas.prototype.initEvents = function () {
        var eventController = new EventController({
            canvas: this,
        });
        eventController.init();
        this.set('eventController', eventController);
    };
    // 覆盖基类中的 clearEvents 方法
    Canvas.prototype.clearEvents = function () {
        var eventController = this.get('eventController');
        eventController.destroy();
    };
    return Canvas;
}(AbstractCanvas));
export default Canvas;
//# sourceMappingURL=canvas.js.map