/**
 * @fileoverview path
 * @author dengfuping_develop@163.com
 */
import { __extends } from "tslib";
import { each, isArray, isBoolean } from '@antv/util';
import { SVG_ATTR_MAP } from '../constant';
import ShapeBase from './base';
var Path = /** @class */ (function (_super) {
    __extends(Path, _super);
    function Path() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.type = 'path';
        _this.canFill = true;
        _this.canStroke = true;
        return _this;
    }
    Path.prototype.createPath = function (context, targetAttrs) {
        var _this = this;
        var attrs = this.attr();
        var el = this.get('el');
        each(targetAttrs || attrs, function (value, attr) {
            if (attr === 'path' && isArray(value)) {
                el.setAttribute('d', _this._formatPath(value));
            }
            else if (attr === 'startArrow' || attr === 'endArrow') {
                var id = isBoolean(value)
                    ? context.getDefaultArrow(attrs, SVG_ATTR_MAP[attr])
                    : context.addArrow(attrs, SVG_ATTR_MAP[attr]);
                el.setAttribute(SVG_ATTR_MAP[attr], "url(#" + id + ")");
            }
            else if (SVG_ATTR_MAP[attr]) {
                el.setAttribute(SVG_ATTR_MAP[attr], value);
            }
        });
    };
    Path.prototype._formatPath = function (value) {
        var newValue = value
            .map(function (path) {
            return path.join(' ');
        })
            .join('');
        if (~newValue.indexOf('NaN')) {
            return '';
        }
        return newValue;
    };
    return Path;
}(ShapeBase));
export default Path;
//# sourceMappingURL=path.js.map