"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var g_base_1 = require("@antv/g-base");
var draw_1 = require("./util/draw");
var svg_1 = require("./util/svg");
var dom_1 = require("./util/dom");
var event_contoller_1 = require("@antv/g-base/lib/event/event-contoller");
var Shape = require("./shape");
var group_1 = require("./group");
var defs_1 = require("./defs");
var Canvas = /** @class */ (function (_super) {
    tslib_1.__extends(Canvas, _super);
    function Canvas(cfg) {
        return _super.call(this, tslib_1.__assign(tslib_1.__assign({}, cfg), { autoDraw: true })) || this;
    }
    // 覆盖基类中的 set 方法
    Canvas.prototype.set = function (name, value) {
        // autoDraw 不可修改，始终为 true
        // TODO: 应该在控制台给出 Warning 提示，引导用户避免这种用法。需要在 @antv/util 中提供通用的 warning 方法，便于在其他 antv 项目中使用
        if (name === 'autoDraw') {
            this.cfg[name] = true;
        }
        else {
            _super.prototype.set.call(this, name, value);
        }
    };
    /**
     * 一些方法调用会引起画布变化
     * @param {ChangeType} changeType 改变的类型
     */
    Canvas.prototype.onCanvasChange = function (changeType) {
        var context = this.get('context');
        var el = this.get('el');
        if (changeType === 'sort') {
            var children_1 = this.get('children');
            if (children_1 && children_1.length) {
                dom_1.sortDom(this, function (a, b) {
                    return children_1.indexOf(a) - children_1.indexOf(b) ? 1 : 0;
                });
            }
        }
        else if (changeType === 'clear') {
            // el is null for canvas
            if (el) {
                el.innerHTML = '';
            }
        }
        else if (changeType === 'matrix') {
            svg_1.setTransform(this);
        }
        else if (changeType === 'clip') {
            this.applyClip(context);
        }
        else if (changeType === 'changeSize') {
            el.setAttribute('width', "" + this.get('width'));
            el.setAttribute('height', "" + this.get('height'));
        }
    };
    Canvas.prototype.getShapeBase = function () {
        return Shape;
    };
    Canvas.prototype.getGroupBase = function () {
        return group_1.default;
    };
    // 复写基类的方法生成标签
    Canvas.prototype.createDom = function () {
        var element = document.createElementNS('http://www.w3.org/2000/svg', 'svg');
        var context = new defs_1.default(element);
        element.setAttribute('width', "" + this.get('width'));
        element.setAttribute('height', "" + this.get('height'));
        // 缓存 context 对象
        this.set('context', context);
        return element;
    };
    // 复写基类的 draw 方法
    Canvas.prototype.draw = function () {
        var context = this.get('context');
        this.applyClip(context);
        this.drawPath(context);
    };
    Canvas.prototype.applyClip = function (context) {
        var children = this.getChildren();
        svg_1.setClip(this, context);
        if (children.length) {
            draw_1.applyClipChildren(context, children);
        }
    };
    Canvas.prototype.drawPath = function (context) {
        var children = this.getChildren();
        if (children.length) {
            draw_1.drawPathChildren(context, children);
        }
    };
    // 覆盖基类中的 initEvents 方法
    Canvas.prototype.initEvents = function () {
        var eventController = new event_contoller_1.default({
            canvas: this,
        });
        eventController.init();
        this.set('eventController', eventController);
    };
    // 覆盖基类中的 clearEvents 方法
    Canvas.prototype.clearEvents = function () {
        var eventController = this.get('eventController');
        eventController.destroy();
    };
    return Canvas;
}(g_base_1.AbstractCanvas));
exports.default = Canvas;
//# sourceMappingURL=canvas.js.map